@@ -13,7 +13,7 @@ module Msf
         property_value = property[:value].strip
         if property_name =~ %r{(smd/agent/|sld/usr|sld/pwd)}i
           # BASE64 decode and parse property value
-          string_type, string_len, string_val = Rex::Text.decode_base64(property[:value].sub('\\=', '=')).split(/\|/)
+          string_type, string_len, string_val = Rex::Text.decode_base64(property[:value].sub('\\=', '=')).split('|')
           if string_len.to_i > 0 && string_type == 'java.lang.String'
             property_value = string_val.first(string_len.to_i)
           else
