@@ -612,7 +612,7 @@ module Msf
       report_note(
         :host => ip,
         :type => 'bap.clicks',
-        :data => data,
+        :data => { :csv_data => data },
         :update => :unique)
     end
 
