@@ -119,6 +119,7 @@ PROCESS_EXECUTE_FLAG_DESKTOP          = (1 << 4)
 PROCESS_EXECUTE_FLAG_SESSION          = (1 << 5)
 PROCESS_EXECUTE_FLAG_SUBSHELL         = (1 << 6)
 PROCESS_EXECUTE_FLAG_PTY              = (1 << 7)
+PROCESS_EXECUTE_FLAG_ARG_ARRAY        = (1 << 8)
 
 # Registry
 TLV_TYPE_HKEY               = TLV_META_TYPE_QWORD   | 1000
@@ -151,25 +152,27 @@ TLV_TYPE_ENV_GROUP          = TLV_META_TYPE_GROUP   | 1102
 DELETE_KEY_FLAG_RECURSIVE   = (1 << 0)
 
 # Process
-TLV_TYPE_BASE_ADDRESS       = TLV_META_TYPE_QWORD   | 2000
-TLV_TYPE_ALLOCATION_TYPE    = TLV_META_TYPE_UINT    | 2001
-TLV_TYPE_PROTECTION         = TLV_META_TYPE_UINT    | 2002
-TLV_TYPE_PROCESS_PERMS      = TLV_META_TYPE_UINT    | 2003
-TLV_TYPE_PROCESS_MEMORY     = TLV_META_TYPE_RAW     | 2004
-TLV_TYPE_ALLOC_BASE_ADDRESS = TLV_META_TYPE_QWORD   | 2005
-TLV_TYPE_MEMORY_STATE       = TLV_META_TYPE_UINT    | 2006
-TLV_TYPE_MEMORY_TYPE        = TLV_META_TYPE_UINT    | 2007
-TLV_TYPE_ALLOC_PROTECTION   = TLV_META_TYPE_UINT    | 2008
-TLV_TYPE_PID                = TLV_META_TYPE_UINT    | 2300
-TLV_TYPE_PROCESS_NAME       = TLV_META_TYPE_STRING  | 2301
-TLV_TYPE_PROCESS_PATH       = TLV_META_TYPE_STRING  | 2302
-TLV_TYPE_PROCESS_GROUP      = TLV_META_TYPE_GROUP   | 2303
-TLV_TYPE_PROCESS_FLAGS      = TLV_META_TYPE_UINT    | 2304
-TLV_TYPE_PROCESS_ARGUMENTS  = TLV_META_TYPE_STRING  | 2305
-TLV_TYPE_PROCESS_ARCH       = TLV_META_TYPE_UINT    | 2306
-TLV_TYPE_PARENT_PID         = TLV_META_TYPE_UINT    | 2307
-TLV_TYPE_PROCESS_SESSION    = TLV_META_TYPE_UINT    | 2308
-TLV_TYPE_PROCESS_ARCH_NAME  = TLV_META_TYPE_STRING  | 2309
+TLV_TYPE_BASE_ADDRESS           = TLV_META_TYPE_QWORD   | 2000
+TLV_TYPE_ALLOCATION_TYPE        = TLV_META_TYPE_UINT    | 2001
+TLV_TYPE_PROTECTION             = TLV_META_TYPE_UINT    | 2002
+TLV_TYPE_PROCESS_PERMS          = TLV_META_TYPE_UINT    | 2003
+TLV_TYPE_PROCESS_MEMORY         = TLV_META_TYPE_RAW     | 2004
+TLV_TYPE_ALLOC_BASE_ADDRESS     = TLV_META_TYPE_QWORD   | 2005
+TLV_TYPE_MEMORY_STATE           = TLV_META_TYPE_UINT    | 2006
+TLV_TYPE_MEMORY_TYPE            = TLV_META_TYPE_UINT    | 2007
+TLV_TYPE_ALLOC_PROTECTION       = TLV_META_TYPE_UINT    | 2008
+TLV_TYPE_PID                    = TLV_META_TYPE_UINT    | 2300
+TLV_TYPE_PROCESS_NAME           = TLV_META_TYPE_STRING  | 2301
+TLV_TYPE_PROCESS_PATH           = TLV_META_TYPE_STRING  | 2302
+TLV_TYPE_PROCESS_GROUP          = TLV_META_TYPE_GROUP   | 2303
+TLV_TYPE_PROCESS_FLAGS          = TLV_META_TYPE_UINT    | 2304
+TLV_TYPE_PROCESS_ARGUMENTS      = TLV_META_TYPE_STRING  | 2305
+TLV_TYPE_PROCESS_ARCH           = TLV_META_TYPE_UINT    | 2306
+TLV_TYPE_PARENT_PID             = TLV_META_TYPE_UINT    | 2307
+TLV_TYPE_PROCESS_SESSION        = TLV_META_TYPE_UINT    | 2308
+TLV_TYPE_PROCESS_ARCH_NAME      = TLV_META_TYPE_STRING  | 2309
+TLV_TYPE_PROCESS_ARGUMENT       = TLV_META_TYPE_STRING  | 2310
+TLV_TYPE_PROCESS_UNESCAPED_PATH = TLV_META_TYPE_STRING  | 2311
 
 TLV_TYPE_DRIVER_ENTRY       = TLV_META_TYPE_GROUP   | 2320
 TLV_TYPE_DRIVER_BASENAME    = TLV_META_TYPE_STRING  | 2321
