@@ -35,7 +35,8 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'References' => [
           ['CVE', '2011-0807'],
-          ['OSVDB', '71948']
+          ['OSVDB', '71948'],
+          ['ATT&CK', Mitre::Attack::Technique::T1021_REMOTE_SERVICES]
         ],
         'Platform' => ['win', 'linux', 'java'],
         'Targets' => [
